// This file was automatically generated by bifcl from /usr/obj/ports/zeek-8.2.0/zeek-8.2.0/src/analyzer/protocol/smb/types.bif (plugin mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_usr_obj_ports_zeek_8_2_0_build_powerpc_src_analyzer_protocol_smb_types_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _usr_obj_ports_zeek_8_2_0_build_powerpc_src_analyzer_protocol_smb_types_bif
#define _usr_obj_ports_zeek_8_2_0_build_powerpc_src_analyzer_protocol_smb_types_bif
#include "zeek/zeek-bif.h"
#endif
#endif

namespace zeek::BifType::Record::SMB { extern zeek::IntrusivePtr<zeek::RecordType> MACTimes; }
namespace zeek::BifType::Record::SMB1 { extern zeek::IntrusivePtr<zeek::RecordType> Header; }
namespace zeek::BifType::Record::SMB2 { extern zeek::IntrusivePtr<zeek::RecordType> Header; }
namespace zeek::BifType::Record::SMB2 { extern zeek::IntrusivePtr<zeek::RecordType> GUID; }
namespace zeek::BifType::Record::SMB2 { extern zeek::IntrusivePtr<zeek::RecordType> FileAttrs; }
namespace zeek::BifType::Record::SMB2 { extern zeek::IntrusivePtr<zeek::RecordType> Fscontrol; }
namespace zeek::BifType::Record::SMB2 { extern zeek::IntrusivePtr<zeek::RecordType> FileEA; }
namespace zeek::BifType::Vector::SMB2 { extern zeek::IntrusivePtr<zeek::VectorType> FileEAs; }
namespace zeek::BifType::Record::SMB2 { extern zeek::IntrusivePtr<zeek::RecordType> PreAuthIntegrityCapabilities; }
namespace zeek::BifType::Record::SMB2 { extern zeek::IntrusivePtr<zeek::RecordType> EncryptionCapabilities; }
namespace zeek::BifType::Record::SMB2 { extern zeek::IntrusivePtr<zeek::RecordType> CompressionCapabilities; }
namespace zeek::BifType::Record::SMB2 { extern zeek::IntrusivePtr<zeek::RecordType> NegotiateContextValue; }
namespace zeek::BifType::Vector::SMB2 { extern zeek::IntrusivePtr<zeek::VectorType> NegotiateContextValues; }

#endif
